package com.ruoyi.ai.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiSampleAmountRecord;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 体验金领取记录Service接口
 * 
 * @author shi
 * @date 2025-11-13
 */
public interface IAiSampleAmountRecordService {

    /**
     * 查询体验金领取记录
     * 
     * @param id 体验金领取记录主键
     * @return 体验金领取记录
     */
    AiSampleAmountRecord selectAiSampleAmountRecordById(Long id);

    /**
     * 查询体验金领取记录列表
     * 
     * @param aiSampleAmountRecord 体验金领取记录
     * @return 体验金领取记录集合
     */
    List<AiSampleAmountRecord> selectAiSampleAmountRecordList(AiSampleAmountRecord aiSampleAmountRecord);

    /**
     * 分页查询体验金领取记录列表
     *
     * @param aiSampleAmountRecord 体验金领取记录
     * @return 体验金领取记录集合
     */
    IPage<AiSampleAmountRecord> selectAiSampleAmountRecordPage(Page page, AiSampleAmountRecord aiSampleAmountRecord);

    /**
     * 新增体验金领取记录
     * 
     * @param aiSampleAmountRecord 体验金领取记录
     * @return 结果
     */
    int insertAiSampleAmountRecord(AiSampleAmountRecord aiSampleAmountRecord);

    /**
     * 修改体验金领取记录
     * 
     * @param aiSampleAmountRecord 体验金领取记录
     * @return 结果
     */
    int updateAiSampleAmountRecord(AiSampleAmountRecord aiSampleAmountRecord);

    /**
     * 批量删除体验金领取记录
     * 
     * @param ids 需要删除的体验金领取记录主键集合
     * @return 结果
     */
    int deleteAiSampleAmountRecordByIds(Long[] ids);

    /**
     * 删除体验金领取记录信息
     * 
     * @param id 体验金领取记录主键
     * @return 结果
     */
    int deleteAiSampleAmountRecordById(Long id);

    AiSampleAmountRecord getAiSampleAmountRecordByUserId(String userId);
}
